/**
  *  \file client/dialogs/combatdlg.cc
  */

#include "client/dialogs/combatdlg.h"
#include "client/widgets/combatdiagram.h"
#include "util/progress.h"
#include "ui/window.h"
#include "ui/widgets/button.h"
#include "client/widgets/racelist.h"
#include "ui/layout.h"
#include "game/vcrdb.h"
#include "ui/widget-busy.h"
#include "ui/uiglobal.h"
#include "util/nls.h"
#include "gfx/palette.h"
#include "ui/widgets/keytranslator.h"

void
doCombatDialog(GClassicVcrDatabase& db)
{
    // Need at least two VCRs
    if (db.getCount() < 2)
        return;

    // Initialize
    WCombatDiagram diag;
    {
        ProgressMonitor progress;
        UIBusyWidget busy;
        ui_root->add(busy);
        ui_root->performDeferredRedraws();
        progress.sig_tick.add(&busy, &UIBusyWidget::tick);

        diag.init(db, progress);
    }

    // Display dialog
    // VBox
    //   WCombatDiagramWidget
    //   WRaceList
    //   HBox
    //     UIButton "OK"
    //     UISpacer

    ObjectHolder h;
    UIWindow& win = h.add(new UIWindow(_("Combat Overview"), UIWindow::BLUE_WINDOW, COLOR_GRAY));
    win.setLayout(UIVBoxLayout::instance5);
    win.add(h.add(new WCombatDiagramWidget(db, diag)));
    win.add(h.add(new WRaceList(30*font_ems[FONT_NORMAL], WRaceList::FlowLayout | WRaceList::ShowRaceNames, 1, NUM_OWNERS)));

    UIGroup& g = h.add(new UIGroup(UIHBoxLayout::instance5));
    g.add(h.add(new UIButton(1, _("Close"), SDLK_RETURN)).addStop());
    g.add(h.add(new UISpacer()));
    win.add(g);
    win.add(h.add(new UIKeyTranslator()).addStop(' ', 1).addStop(SDLK_ESCAPE, 1));

    GfxRect pos = ui_root->getExtent();
    pos.grow(-10, -10);
    win.setExtent(pos);
    ui_root->runModal(win);
}
